# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class StartProcessInstanceDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'business_key': 'str',
        'variables': 'dict(str, VariableValueDto)',
        'case_instance_id': 'str',
        'start_instructions': 'list[ProcessInstanceModificationInstructionDto]',
        'skip_custom_listeners': 'bool',
        'skip_io_mappings': 'bool',
        'with_variables_in_return': 'bool'
    }

    attribute_map = {
        'business_key': 'businessKey',
        'variables': 'variables',
        'case_instance_id': 'caseInstanceId',
        'start_instructions': 'startInstructions',
        'skip_custom_listeners': 'skipCustomListeners',
        'skip_io_mappings': 'skipIoMappings',
        'with_variables_in_return': 'withVariablesInReturn'
    }

    def __init__(self, business_key=None, variables=None, case_instance_id=None, start_instructions=None, skip_custom_listeners=None, skip_io_mappings=None, with_variables_in_return=None, local_vars_configuration=None):  # noqa: E501
        """StartProcessInstanceDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._business_key = None
        self._variables = None
        self._case_instance_id = None
        self._start_instructions = None
        self._skip_custom_listeners = None
        self._skip_io_mappings = None
        self._with_variables_in_return = None
        self.discriminator = None

        if business_key is not None:
            self.business_key = business_key
        if variables is not None:
            self.variables = variables
        if case_instance_id is not None:
            self.case_instance_id = case_instance_id
        if start_instructions is not None:
            self.start_instructions = start_instructions
        self.skip_custom_listeners = skip_custom_listeners
        self.skip_io_mappings = skip_io_mappings
        self.with_variables_in_return = with_variables_in_return

    @property
    def business_key(self):
        """Gets the business_key of this StartProcessInstanceDto.  # noqa: E501

        The business key of the process instance.  # noqa: E501

        :return: The business_key of this StartProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._business_key

    @business_key.setter
    def business_key(self, business_key):
        """Sets the business_key of this StartProcessInstanceDto.

        The business key of the process instance.  # noqa: E501

        :param business_key: The business_key of this StartProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._business_key = business_key

    @property
    def variables(self):
        """Gets the variables of this StartProcessInstanceDto.  # noqa: E501


        :return: The variables of this StartProcessInstanceDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this StartProcessInstanceDto.


        :param variables: The variables of this StartProcessInstanceDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._variables = variables

    @property
    def case_instance_id(self):
        """Gets the case_instance_id of this StartProcessInstanceDto.  # noqa: E501

        The case instance id the process instance is to be initialized with.  # noqa: E501

        :return: The case_instance_id of this StartProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._case_instance_id

    @case_instance_id.setter
    def case_instance_id(self, case_instance_id):
        """Sets the case_instance_id of this StartProcessInstanceDto.

        The case instance id the process instance is to be initialized with.  # noqa: E501

        :param case_instance_id: The case_instance_id of this StartProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._case_instance_id = case_instance_id

    @property
    def start_instructions(self):
        """Gets the start_instructions of this StartProcessInstanceDto.  # noqa: E501

        **Optional**. A JSON array of instructions that specify which activities to start the process instance at. If this property is omitted, the process instance starts at its default blank start event.  # noqa: E501

        :return: The start_instructions of this StartProcessInstanceDto.  # noqa: E501
        :rtype: list[ProcessInstanceModificationInstructionDto]
        """
        return self._start_instructions

    @start_instructions.setter
    def start_instructions(self, start_instructions):
        """Sets the start_instructions of this StartProcessInstanceDto.

        **Optional**. A JSON array of instructions that specify which activities to start the process instance at. If this property is omitted, the process instance starts at its default blank start event.  # noqa: E501

        :param start_instructions: The start_instructions of this StartProcessInstanceDto.  # noqa: E501
        :type: list[ProcessInstanceModificationInstructionDto]
        """

        self._start_instructions = start_instructions

    @property
    def skip_custom_listeners(self):
        """Gets the skip_custom_listeners of this StartProcessInstanceDto.  # noqa: E501

        Skip execution listener invocation for activities that are started or ended as part of this request. **Note**: This option is currently only respected when start instructions are submitted via the `startInstructions` property.  # noqa: E501

        :return: The skip_custom_listeners of this StartProcessInstanceDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_custom_listeners

    @skip_custom_listeners.setter
    def skip_custom_listeners(self, skip_custom_listeners):
        """Sets the skip_custom_listeners of this StartProcessInstanceDto.

        Skip execution listener invocation for activities that are started or ended as part of this request. **Note**: This option is currently only respected when start instructions are submitted via the `startInstructions` property.  # noqa: E501

        :param skip_custom_listeners: The skip_custom_listeners of this StartProcessInstanceDto.  # noqa: E501
        :type: bool
        """

        self._skip_custom_listeners = skip_custom_listeners

    @property
    def skip_io_mappings(self):
        """Gets the skip_io_mappings of this StartProcessInstanceDto.  # noqa: E501

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started or ended as part of this request. **Note**: This option is currently only respected when start instructions are submitted via the `startInstructions` property.  # noqa: E501

        :return: The skip_io_mappings of this StartProcessInstanceDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_io_mappings

    @skip_io_mappings.setter
    def skip_io_mappings(self, skip_io_mappings):
        """Sets the skip_io_mappings of this StartProcessInstanceDto.

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started or ended as part of this request. **Note**: This option is currently only respected when start instructions are submitted via the `startInstructions` property.  # noqa: E501

        :param skip_io_mappings: The skip_io_mappings of this StartProcessInstanceDto.  # noqa: E501
        :type: bool
        """

        self._skip_io_mappings = skip_io_mappings

    @property
    def with_variables_in_return(self):
        """Gets the with_variables_in_return of this StartProcessInstanceDto.  # noqa: E501

        Indicates if the variables, which was used by the process instance during execution, should be returned. Default value: `false`  # noqa: E501

        :return: The with_variables_in_return of this StartProcessInstanceDto.  # noqa: E501
        :rtype: bool
        """
        return self._with_variables_in_return

    @with_variables_in_return.setter
    def with_variables_in_return(self, with_variables_in_return):
        """Sets the with_variables_in_return of this StartProcessInstanceDto.

        Indicates if the variables, which was used by the process instance during execution, should be returned. Default value: `false`  # noqa: E501

        :param with_variables_in_return: The with_variables_in_return of this StartProcessInstanceDto.  # noqa: E501
        :type: bool
        """

        self._with_variables_in_return = with_variables_in_return

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartProcessInstanceDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StartProcessInstanceDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from generic_camunda_client.api_client import ApiClient
from generic_camunda_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class IncidentApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_incident(self, id, **kwargs):  # noqa: E501
        """Get Incident  # noqa: E501

        Retrieves an incident by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_incident(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the incident to be retrieved. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: IncidentDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_incident_with_http_info(id, **kwargs)  # noqa: E501

    def get_incident_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Incident  # noqa: E501

        Retrieves an incident by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_incident_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the incident to be retrieved. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(IncidentDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_incident" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_incident`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/incident/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IncidentDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_incidents(self, **kwargs):  # noqa: E501
        """Get List  # noqa: E501

        Queries for incidents that fulfill given parameters. The size of the result set can be retrieved by using the [Get Incident Count](https://docs.camunda.org/manual/7.14/reference/rest/incident/get-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_incidents(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str incident_id: Restricts to incidents that have the given id.
        :param str incident_type: Restricts to incidents that belong to the given incident type. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.
        :param str incident_message: Restricts to incidents that have the given incident message.
        :param str incident_message_like: Restricts to incidents that incidents message is a substring of the given value. The string can include the wildcard character '%' to express like-strategy: starts with (`string%`), ends with (`%string`) or contains (`%string%`).
        :param str process_definition_id: Restricts to incidents that belong to a process definition with the given id.
        :param str process_definition_key_in: Restricts to incidents that belong to a process definition with the given keys. Must be a comma-separated list.
        :param str process_instance_id: Restricts to incidents that belong to a process instance with the given id.
        :param str execution_id: Restricts to incidents that belong to an execution with the given id.
        :param datetime incident_timestamp_before: Restricts to incidents that have an incidentTimestamp date before the given date. By default, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime incident_timestamp_after: Restricts to incidents that have an incidentTimestamp date after the given date. By default*, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str activity_id: Restricts to incidents that belong to an activity with the given id.
        :param str failed_activity_id: Restricts to incidents that were created due to the failure of an activity with the given id.
        :param str cause_incident_id: Restricts to incidents that have the given incident id as cause incident.
        :param str root_cause_incident_id: Restricts to incidents that have the given incident id as root cause incident.
        :param str configuration: Restricts to incidents that have the given parameter set as configuration.
        :param str tenant_id_in: Restricts to incidents that have one of the given comma-separated tenant ids.
        :param str job_definition_id_in: Restricts to incidents that have one of the given comma-separated job definition ids.
        :param str sort_by: Sort the results lexicographically by a given criterion. Must be used in conjunction with the sortOrder parameter.
        :param str sort_order: Sort the results in a given order. Values may be asc for ascending order or desc for descending order. Must be used in conjunction with the sortBy parameter.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[IncidentDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_incidents_with_http_info(**kwargs)  # noqa: E501

    def get_incidents_with_http_info(self, **kwargs):  # noqa: E501
        """Get List  # noqa: E501

        Queries for incidents that fulfill given parameters. The size of the result set can be retrieved by using the [Get Incident Count](https://docs.camunda.org/manual/7.14/reference/rest/incident/get-query-count/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_incidents_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str incident_id: Restricts to incidents that have the given id.
        :param str incident_type: Restricts to incidents that belong to the given incident type. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.
        :param str incident_message: Restricts to incidents that have the given incident message.
        :param str incident_message_like: Restricts to incidents that incidents message is a substring of the given value. The string can include the wildcard character '%' to express like-strategy: starts with (`string%`), ends with (`%string`) or contains (`%string%`).
        :param str process_definition_id: Restricts to incidents that belong to a process definition with the given id.
        :param str process_definition_key_in: Restricts to incidents that belong to a process definition with the given keys. Must be a comma-separated list.
        :param str process_instance_id: Restricts to incidents that belong to a process instance with the given id.
        :param str execution_id: Restricts to incidents that belong to an execution with the given id.
        :param datetime incident_timestamp_before: Restricts to incidents that have an incidentTimestamp date before the given date. By default, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime incident_timestamp_after: Restricts to incidents that have an incidentTimestamp date after the given date. By default*, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str activity_id: Restricts to incidents that belong to an activity with the given id.
        :param str failed_activity_id: Restricts to incidents that were created due to the failure of an activity with the given id.
        :param str cause_incident_id: Restricts to incidents that have the given incident id as cause incident.
        :param str root_cause_incident_id: Restricts to incidents that have the given incident id as root cause incident.
        :param str configuration: Restricts to incidents that have the given parameter set as configuration.
        :param str tenant_id_in: Restricts to incidents that have one of the given comma-separated tenant ids.
        :param str job_definition_id_in: Restricts to incidents that have one of the given comma-separated job definition ids.
        :param str sort_by: Sort the results lexicographically by a given criterion. Must be used in conjunction with the sortOrder parameter.
        :param str sort_order: Sort the results in a given order. Values may be asc for ascending order or desc for descending order. Must be used in conjunction with the sortBy parameter.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[IncidentDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'incident_id',
            'incident_type',
            'incident_message',
            'incident_message_like',
            'process_definition_id',
            'process_definition_key_in',
            'process_instance_id',
            'execution_id',
            'incident_timestamp_before',
            'incident_timestamp_after',
            'activity_id',
            'failed_activity_id',
            'cause_incident_id',
            'root_cause_incident_id',
            'configuration',
            'tenant_id_in',
            'job_definition_id_in',
            'sort_by',
            'sort_order'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_incidents" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'incident_id' in local_var_params and local_var_params['incident_id'] is not None:  # noqa: E501
            query_params.append(('incidentId', local_var_params['incident_id']))  # noqa: E501
        if 'incident_type' in local_var_params and local_var_params['incident_type'] is not None:  # noqa: E501
            query_params.append(('incidentType', local_var_params['incident_type']))  # noqa: E501
        if 'incident_message' in local_var_params and local_var_params['incident_message'] is not None:  # noqa: E501
            query_params.append(('incidentMessage', local_var_params['incident_message']))  # noqa: E501
        if 'incident_message_like' in local_var_params and local_var_params['incident_message_like'] is not None:  # noqa: E501
            query_params.append(('incidentMessageLike', local_var_params['incident_message_like']))  # noqa: E501
        if 'process_definition_id' in local_var_params and local_var_params['process_definition_id'] is not None:  # noqa: E501
            query_params.append(('processDefinitionId', local_var_params['process_definition_id']))  # noqa: E501
        if 'process_definition_key_in' in local_var_params and local_var_params['process_definition_key_in'] is not None:  # noqa: E501
            query_params.append(('processDefinitionKeyIn', local_var_params['process_definition_key_in']))  # noqa: E501
        if 'process_instance_id' in local_var_params and local_var_params['process_instance_id'] is not None:  # noqa: E501
            query_params.append(('processInstanceId', local_var_params['process_instance_id']))  # noqa: E501
        if 'execution_id' in local_var_params and local_var_params['execution_id'] is not None:  # noqa: E501
            query_params.append(('executionId', local_var_params['execution_id']))  # noqa: E501
        if 'incident_timestamp_before' in local_var_params and local_var_params['incident_timestamp_before'] is not None:  # noqa: E501
            query_params.append(('incidentTimestampBefore', local_var_params['incident_timestamp_before']))  # noqa: E501
        if 'incident_timestamp_after' in local_var_params and local_var_params['incident_timestamp_after'] is not None:  # noqa: E501
            query_params.append(('incidentTimestampAfter', local_var_params['incident_timestamp_after']))  # noqa: E501
        if 'activity_id' in local_var_params and local_var_params['activity_id'] is not None:  # noqa: E501
            query_params.append(('activityId', local_var_params['activity_id']))  # noqa: E501
        if 'failed_activity_id' in local_var_params and local_var_params['failed_activity_id'] is not None:  # noqa: E501
            query_params.append(('failedActivityId', local_var_params['failed_activity_id']))  # noqa: E501
        if 'cause_incident_id' in local_var_params and local_var_params['cause_incident_id'] is not None:  # noqa: E501
            query_params.append(('causeIncidentId', local_var_params['cause_incident_id']))  # noqa: E501
        if 'root_cause_incident_id' in local_var_params and local_var_params['root_cause_incident_id'] is not None:  # noqa: E501
            query_params.append(('rootCauseIncidentId', local_var_params['root_cause_incident_id']))  # noqa: E501
        if 'configuration' in local_var_params and local_var_params['configuration'] is not None:  # noqa: E501
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501
        if 'tenant_id_in' in local_var_params and local_var_params['tenant_id_in'] is not None:  # noqa: E501
            query_params.append(('tenantIdIn', local_var_params['tenant_id_in']))  # noqa: E501
        if 'job_definition_id_in' in local_var_params and local_var_params['job_definition_id_in'] is not None:  # noqa: E501
            query_params.append(('jobDefinitionIdIn', local_var_params['job_definition_id_in']))  # noqa: E501
        if 'sort_by' in local_var_params and local_var_params['sort_by'] is not None:  # noqa: E501
            query_params.append(('sortBy', local_var_params['sort_by']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/incident', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[IncidentDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_incidents_count(self, **kwargs):  # noqa: E501
        """Get List Count  # noqa: E501

        Queries for the number of incidents that fulfill given parameters. Takes the same parameters as the [Get Incidents](https://docs.camunda.org/manual/7.14/reference/rest/incident/get-query/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_incidents_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str incident_id: Restricts to incidents that have the given id.
        :param str incident_type: Restricts to incidents that belong to the given incident type. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.
        :param str incident_message: Restricts to incidents that have the given incident message.
        :param str incident_message_like: Restricts to incidents that incidents message is a substring of the given value. The string can include the wildcard character '%' to express like-strategy: starts with (`string%`), ends with (`%string`) or contains (`%string%`).
        :param str process_definition_id: Restricts to incidents that belong to a process definition with the given id.
        :param str process_definition_key_in: Restricts to incidents that belong to a process definition with the given keys. Must be a comma-separated list.
        :param str process_instance_id: Restricts to incidents that belong to a process instance with the given id.
        :param str execution_id: Restricts to incidents that belong to an execution with the given id.
        :param datetime incident_timestamp_before: Restricts to incidents that have an incidentTimestamp date before the given date. By default, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime incident_timestamp_after: Restricts to incidents that have an incidentTimestamp date after the given date. By default*, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str activity_id: Restricts to incidents that belong to an activity with the given id.
        :param str failed_activity_id: Restricts to incidents that were created due to the failure of an activity with the given id.
        :param str cause_incident_id: Restricts to incidents that have the given incident id as cause incident.
        :param str root_cause_incident_id: Restricts to incidents that have the given incident id as root cause incident.
        :param str configuration: Restricts to incidents that have the given parameter set as configuration.
        :param str tenant_id_in: Restricts to incidents that have one of the given comma-separated tenant ids.
        :param str job_definition_id_in: Restricts to incidents that have one of the given comma-separated job definition ids.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CountResultDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_incidents_count_with_http_info(**kwargs)  # noqa: E501

    def get_incidents_count_with_http_info(self, **kwargs):  # noqa: E501
        """Get List Count  # noqa: E501

        Queries for the number of incidents that fulfill given parameters. Takes the same parameters as the [Get Incidents](https://docs.camunda.org/manual/7.14/reference/rest/incident/get-query/) method.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_incidents_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str incident_id: Restricts to incidents that have the given id.
        :param str incident_type: Restricts to incidents that belong to the given incident type. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.
        :param str incident_message: Restricts to incidents that have the given incident message.
        :param str incident_message_like: Restricts to incidents that incidents message is a substring of the given value. The string can include the wildcard character '%' to express like-strategy: starts with (`string%`), ends with (`%string`) or contains (`%string%`).
        :param str process_definition_id: Restricts to incidents that belong to a process definition with the given id.
        :param str process_definition_key_in: Restricts to incidents that belong to a process definition with the given keys. Must be a comma-separated list.
        :param str process_instance_id: Restricts to incidents that belong to a process instance with the given id.
        :param str execution_id: Restricts to incidents that belong to an execution with the given id.
        :param datetime incident_timestamp_before: Restricts to incidents that have an incidentTimestamp date before the given date. By default, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param datetime incident_timestamp_after: Restricts to incidents that have an incidentTimestamp date after the given date. By default*, the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.
        :param str activity_id: Restricts to incidents that belong to an activity with the given id.
        :param str failed_activity_id: Restricts to incidents that were created due to the failure of an activity with the given id.
        :param str cause_incident_id: Restricts to incidents that have the given incident id as cause incident.
        :param str root_cause_incident_id: Restricts to incidents that have the given incident id as root cause incident.
        :param str configuration: Restricts to incidents that have the given parameter set as configuration.
        :param str tenant_id_in: Restricts to incidents that have one of the given comma-separated tenant ids.
        :param str job_definition_id_in: Restricts to incidents that have one of the given comma-separated job definition ids.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CountResultDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'incident_id',
            'incident_type',
            'incident_message',
            'incident_message_like',
            'process_definition_id',
            'process_definition_key_in',
            'process_instance_id',
            'execution_id',
            'incident_timestamp_before',
            'incident_timestamp_after',
            'activity_id',
            'failed_activity_id',
            'cause_incident_id',
            'root_cause_incident_id',
            'configuration',
            'tenant_id_in',
            'job_definition_id_in'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_incidents_count" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'incident_id' in local_var_params and local_var_params['incident_id'] is not None:  # noqa: E501
            query_params.append(('incidentId', local_var_params['incident_id']))  # noqa: E501
        if 'incident_type' in local_var_params and local_var_params['incident_type'] is not None:  # noqa: E501
            query_params.append(('incidentType', local_var_params['incident_type']))  # noqa: E501
        if 'incident_message' in local_var_params and local_var_params['incident_message'] is not None:  # noqa: E501
            query_params.append(('incidentMessage', local_var_params['incident_message']))  # noqa: E501
        if 'incident_message_like' in local_var_params and local_var_params['incident_message_like'] is not None:  # noqa: E501
            query_params.append(('incidentMessageLike', local_var_params['incident_message_like']))  # noqa: E501
        if 'process_definition_id' in local_var_params and local_var_params['process_definition_id'] is not None:  # noqa: E501
            query_params.append(('processDefinitionId', local_var_params['process_definition_id']))  # noqa: E501
        if 'process_definition_key_in' in local_var_params and local_var_params['process_definition_key_in'] is not None:  # noqa: E501
            query_params.append(('processDefinitionKeyIn', local_var_params['process_definition_key_in']))  # noqa: E501
        if 'process_instance_id' in local_var_params and local_var_params['process_instance_id'] is not None:  # noqa: E501
            query_params.append(('processInstanceId', local_var_params['process_instance_id']))  # noqa: E501
        if 'execution_id' in local_var_params and local_var_params['execution_id'] is not None:  # noqa: E501
            query_params.append(('executionId', local_var_params['execution_id']))  # noqa: E501
        if 'incident_timestamp_before' in local_var_params and local_var_params['incident_timestamp_before'] is not None:  # noqa: E501
            query_params.append(('incidentTimestampBefore', local_var_params['incident_timestamp_before']))  # noqa: E501
        if 'incident_timestamp_after' in local_var_params and local_var_params['incident_timestamp_after'] is not None:  # noqa: E501
            query_params.append(('incidentTimestampAfter', local_var_params['incident_timestamp_after']))  # noqa: E501
        if 'activity_id' in local_var_params and local_var_params['activity_id'] is not None:  # noqa: E501
            query_params.append(('activityId', local_var_params['activity_id']))  # noqa: E501
        if 'failed_activity_id' in local_var_params and local_var_params['failed_activity_id'] is not None:  # noqa: E501
            query_params.append(('failedActivityId', local_var_params['failed_activity_id']))  # noqa: E501
        if 'cause_incident_id' in local_var_params and local_var_params['cause_incident_id'] is not None:  # noqa: E501
            query_params.append(('causeIncidentId', local_var_params['cause_incident_id']))  # noqa: E501
        if 'root_cause_incident_id' in local_var_params and local_var_params['root_cause_incident_id'] is not None:  # noqa: E501
            query_params.append(('rootCauseIncidentId', local_var_params['root_cause_incident_id']))  # noqa: E501
        if 'configuration' in local_var_params and local_var_params['configuration'] is not None:  # noqa: E501
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501
        if 'tenant_id_in' in local_var_params and local_var_params['tenant_id_in'] is not None:  # noqa: E501
            query_params.append(('tenantIdIn', local_var_params['tenant_id_in']))  # noqa: E501
        if 'job_definition_id_in' in local_var_params and local_var_params['job_definition_id_in'] is not None:  # noqa: E501
            query_params.append(('jobDefinitionIdIn', local_var_params['job_definition_id_in']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/incident/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CountResultDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resolve_incident(self, id, **kwargs):  # noqa: E501
        """Resolve Incident  # noqa: E501

        Resolves an incident with given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resolve_incident(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the incident to be resolved. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.resolve_incident_with_http_info(id, **kwargs)  # noqa: E501

    def resolve_incident_with_http_info(self, id, **kwargs):  # noqa: E501
        """Resolve Incident  # noqa: E501

        Resolves an incident with given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resolve_incident_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The id of the incident to be resolved. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resolve_incident" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `resolve_incident`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/incident/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class StartProcessInstanceFormDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'variables': 'dict(str, VariableValueDto)',
        'business_key': 'str'
    }

    attribute_map = {
        'variables': 'variables',
        'business_key': 'businessKey'
    }

    def __init__(self, variables=None, business_key=None, local_vars_configuration=None):  # noqa: E501
        """StartProcessInstanceFormDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._variables = None
        self._business_key = None
        self.discriminator = None

        if variables is not None:
            self.variables = variables
        if business_key is not None:
            self.business_key = business_key

    @property
    def variables(self):
        """Gets the variables of this StartProcessInstanceFormDto.  # noqa: E501


        :return: The variables of this StartProcessInstanceFormDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this StartProcessInstanceFormDto.


        :param variables: The variables of this StartProcessInstanceFormDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._variables = variables

    @property
    def business_key(self):
        """Gets the business_key of this StartProcessInstanceFormDto.  # noqa: E501

        The business key the process instance is to be initialized with. The business key uniquely identifies the process instance in the context of the given process definition.  # noqa: E501

        :return: The business_key of this StartProcessInstanceFormDto.  # noqa: E501
        :rtype: str
        """
        return self._business_key

    @business_key.setter
    def business_key(self, business_key):
        """Sets the business_key of this StartProcessInstanceFormDto.

        The business key the process instance is to be initialized with. The business key uniquely identifies the process instance in the context of the given process definition.  # noqa: E501

        :param business_key: The business_key of this StartProcessInstanceFormDto.  # noqa: E501
        :type: str
        """

        self._business_key = business_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartProcessInstanceFormDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StartProcessInstanceFormDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ProcessInstanceSuspensionStateAsyncDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'suspended': 'bool',
        'process_instance_ids': 'list[str]',
        'process_instance_query': 'ProcessInstanceQueryDto',
        'historic_process_instance_query': 'HistoricProcessInstanceQueryDto'
    }

    attribute_map = {
        'suspended': 'suspended',
        'process_instance_ids': 'processInstanceIds',
        'process_instance_query': 'processInstanceQuery',
        'historic_process_instance_query': 'historicProcessInstanceQuery'
    }

    def __init__(self, suspended=None, process_instance_ids=None, process_instance_query=None, historic_process_instance_query=None, local_vars_configuration=None):  # noqa: E501
        """ProcessInstanceSuspensionStateAsyncDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._suspended = None
        self._process_instance_ids = None
        self._process_instance_query = None
        self._historic_process_instance_query = None
        self.discriminator = None

        self.suspended = suspended
        if process_instance_ids is not None:
            self.process_instance_ids = process_instance_ids
        if process_instance_query is not None:
            self.process_instance_query = process_instance_query
        if historic_process_instance_query is not None:
            self.historic_process_instance_query = historic_process_instance_query

    @property
    def suspended(self):
        """Gets the suspended of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501

        A Boolean value which indicates whether to activate or suspend a given process instance. When the value is set to true, the given process instance will be suspended and when the value is set to false, the given process instance will be activated.  # noqa: E501

        :return: The suspended of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :rtype: bool
        """
        return self._suspended

    @suspended.setter
    def suspended(self, suspended):
        """Sets the suspended of this ProcessInstanceSuspensionStateAsyncDto.

        A Boolean value which indicates whether to activate or suspend a given process instance. When the value is set to true, the given process instance will be suspended and when the value is set to false, the given process instance will be activated.  # noqa: E501

        :param suspended: The suspended of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :type: bool
        """

        self._suspended = suspended

    @property
    def process_instance_ids(self):
        """Gets the process_instance_ids of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501

        A list of process instance ids which defines a group of process instances which will be activated or suspended by the operation.  # noqa: E501

        :return: The process_instance_ids of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_instance_ids

    @process_instance_ids.setter
    def process_instance_ids(self, process_instance_ids):
        """Sets the process_instance_ids of this ProcessInstanceSuspensionStateAsyncDto.

        A list of process instance ids which defines a group of process instances which will be activated or suspended by the operation.  # noqa: E501

        :param process_instance_ids: The process_instance_ids of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :type: list[str]
        """

        self._process_instance_ids = process_instance_ids

    @property
    def process_instance_query(self):
        """Gets the process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501


        :return: The process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :rtype: ProcessInstanceQueryDto
        """
        return self._process_instance_query

    @process_instance_query.setter
    def process_instance_query(self, process_instance_query):
        """Sets the process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.


        :param process_instance_query: The process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :type: ProcessInstanceQueryDto
        """

        self._process_instance_query = process_instance_query

    @property
    def historic_process_instance_query(self):
        """Gets the historic_process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501


        :return: The historic_process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :rtype: HistoricProcessInstanceQueryDto
        """
        return self._historic_process_instance_query

    @historic_process_instance_query.setter
    def historic_process_instance_query(self, historic_process_instance_query):
        """Sets the historic_process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.


        :param historic_process_instance_query: The historic_process_instance_query of this ProcessInstanceSuspensionStateAsyncDto.  # noqa: E501
        :type: HistoricProcessInstanceQueryDto
        """

        self._historic_process_instance_query = historic_process_instance_query

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessInstanceSuspensionStateAsyncDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProcessInstanceSuspensionStateAsyncDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ProcessDefinitionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'key': 'str',
        'category': 'str',
        'description': 'str',
        'name': 'str',
        'version': 'int',
        'resource': 'str',
        'deployment_id': 'str',
        'diagram': 'str',
        'suspended': 'bool',
        'tenant_id': 'str',
        'version_tag': 'str',
        'history_time_to_live': 'int',
        'startable_in_tasklist': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'key': 'key',
        'category': 'category',
        'description': 'description',
        'name': 'name',
        'version': 'version',
        'resource': 'resource',
        'deployment_id': 'deploymentId',
        'diagram': 'diagram',
        'suspended': 'suspended',
        'tenant_id': 'tenantId',
        'version_tag': 'versionTag',
        'history_time_to_live': 'historyTimeToLive',
        'startable_in_tasklist': 'startableInTasklist'
    }

    def __init__(self, id=None, key=None, category=None, description=None, name=None, version=None, resource=None, deployment_id=None, diagram=None, suspended=None, tenant_id=None, version_tag=None, history_time_to_live=None, startable_in_tasklist=None, local_vars_configuration=None):  # noqa: E501
        """ProcessDefinitionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._key = None
        self._category = None
        self._description = None
        self._name = None
        self._version = None
        self._resource = None
        self._deployment_id = None
        self._diagram = None
        self._suspended = None
        self._tenant_id = None
        self._version_tag = None
        self._history_time_to_live = None
        self._startable_in_tasklist = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if key is not None:
            self.key = key
        if category is not None:
            self.category = category
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if resource is not None:
            self.resource = resource
        if deployment_id is not None:
            self.deployment_id = deployment_id
        if diagram is not None:
            self.diagram = diagram
        if suspended is not None:
            self.suspended = suspended
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if version_tag is not None:
            self.version_tag = version_tag
        self.history_time_to_live = history_time_to_live
        if startable_in_tasklist is not None:
            self.startable_in_tasklist = startable_in_tasklist

    @property
    def id(self):
        """Gets the id of this ProcessDefinitionDto.  # noqa: E501

        The id of the process definition  # noqa: E501

        :return: The id of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProcessDefinitionDto.

        The id of the process definition  # noqa: E501

        :param id: The id of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def key(self):
        """Gets the key of this ProcessDefinitionDto.  # noqa: E501

        The key of the process definition, i.e., the id of the BPMN 2.0 XML process definition.  # noqa: E501

        :return: The key of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ProcessDefinitionDto.

        The key of the process definition, i.e., the id of the BPMN 2.0 XML process definition.  # noqa: E501

        :param key: The key of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def category(self):
        """Gets the category of this ProcessDefinitionDto.  # noqa: E501

        The category of the process definition.  # noqa: E501

        :return: The category of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ProcessDefinitionDto.

        The category of the process definition.  # noqa: E501

        :param category: The category of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def description(self):
        """Gets the description of this ProcessDefinitionDto.  # noqa: E501

        The description of the process definition.  # noqa: E501

        :return: The description of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProcessDefinitionDto.

        The description of the process definition.  # noqa: E501

        :param description: The description of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this ProcessDefinitionDto.  # noqa: E501

        The name of the process definition.  # noqa: E501

        :return: The name of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProcessDefinitionDto.

        The name of the process definition.  # noqa: E501

        :param name: The name of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this ProcessDefinitionDto.  # noqa: E501

        The version of the process definition that the engine assigned to it.  # noqa: E501

        :return: The version of this ProcessDefinitionDto.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProcessDefinitionDto.

        The version of the process definition that the engine assigned to it.  # noqa: E501

        :param version: The version of this ProcessDefinitionDto.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def resource(self):
        """Gets the resource of this ProcessDefinitionDto.  # noqa: E501

        The file name of the process definition.  # noqa: E501

        :return: The resource of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this ProcessDefinitionDto.

        The file name of the process definition.  # noqa: E501

        :param resource: The resource of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._resource = resource

    @property
    def deployment_id(self):
        """Gets the deployment_id of this ProcessDefinitionDto.  # noqa: E501

        The deployment id of the process definition.  # noqa: E501

        :return: The deployment_id of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._deployment_id

    @deployment_id.setter
    def deployment_id(self, deployment_id):
        """Sets the deployment_id of this ProcessDefinitionDto.

        The deployment id of the process definition.  # noqa: E501

        :param deployment_id: The deployment_id of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._deployment_id = deployment_id

    @property
    def diagram(self):
        """Gets the diagram of this ProcessDefinitionDto.  # noqa: E501

        The file name of the process definition diagram, if it exists.  # noqa: E501

        :return: The diagram of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._diagram

    @diagram.setter
    def diagram(self, diagram):
        """Sets the diagram of this ProcessDefinitionDto.

        The file name of the process definition diagram, if it exists.  # noqa: E501

        :param diagram: The diagram of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._diagram = diagram

    @property
    def suspended(self):
        """Gets the suspended of this ProcessDefinitionDto.  # noqa: E501

        A flag indicating whether the definition is suspended or not.  # noqa: E501

        :return: The suspended of this ProcessDefinitionDto.  # noqa: E501
        :rtype: bool
        """
        return self._suspended

    @suspended.setter
    def suspended(self, suspended):
        """Sets the suspended of this ProcessDefinitionDto.

        A flag indicating whether the definition is suspended or not.  # noqa: E501

        :param suspended: The suspended of this ProcessDefinitionDto.  # noqa: E501
        :type: bool
        """

        self._suspended = suspended

    @property
    def tenant_id(self):
        """Gets the tenant_id of this ProcessDefinitionDto.  # noqa: E501

        The tenant id of the process definition.  # noqa: E501

        :return: The tenant_id of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this ProcessDefinitionDto.

        The tenant id of the process definition.  # noqa: E501

        :param tenant_id: The tenant_id of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def version_tag(self):
        """Gets the version_tag of this ProcessDefinitionDto.  # noqa: E501

        The version tag of the process definition.  # noqa: E501

        :return: The version_tag of this ProcessDefinitionDto.  # noqa: E501
        :rtype: str
        """
        return self._version_tag

    @version_tag.setter
    def version_tag(self, version_tag):
        """Sets the version_tag of this ProcessDefinitionDto.

        The version tag of the process definition.  # noqa: E501

        :param version_tag: The version_tag of this ProcessDefinitionDto.  # noqa: E501
        :type: str
        """

        self._version_tag = version_tag

    @property
    def history_time_to_live(self):
        """Gets the history_time_to_live of this ProcessDefinitionDto.  # noqa: E501

        History time to live value of the process definition. Is used within [History cleanup](https://docs.camunda.org/manual/7.14/user-guide/process-engine/history/#history-cleanup).  # noqa: E501

        :return: The history_time_to_live of this ProcessDefinitionDto.  # noqa: E501
        :rtype: int
        """
        return self._history_time_to_live

    @history_time_to_live.setter
    def history_time_to_live(self, history_time_to_live):
        """Sets the history_time_to_live of this ProcessDefinitionDto.

        History time to live value of the process definition. Is used within [History cleanup](https://docs.camunda.org/manual/7.14/user-guide/process-engine/history/#history-cleanup).  # noqa: E501

        :param history_time_to_live: The history_time_to_live of this ProcessDefinitionDto.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                history_time_to_live is not None and history_time_to_live < 0):  # noqa: E501
            raise ValueError("Invalid value for `history_time_to_live`, must be a value greater than or equal to `0`")  # noqa: E501

        self._history_time_to_live = history_time_to_live

    @property
    def startable_in_tasklist(self):
        """Gets the startable_in_tasklist of this ProcessDefinitionDto.  # noqa: E501

        A flag indicating whether the process definition is startable in Tasklist or not.  # noqa: E501

        :return: The startable_in_tasklist of this ProcessDefinitionDto.  # noqa: E501
        :rtype: bool
        """
        return self._startable_in_tasklist

    @startable_in_tasklist.setter
    def startable_in_tasklist(self, startable_in_tasklist):
        """Sets the startable_in_tasklist of this ProcessDefinitionDto.

        A flag indicating whether the process definition is startable in Tasklist or not.  # noqa: E501

        :param startable_in_tasklist: The startable_in_tasklist of this ProcessDefinitionDto.  # noqa: E501
        :type: bool
        """

        self._startable_in_tasklist = startable_in_tasklist

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessDefinitionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProcessDefinitionDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class BatchDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'type': 'str',
        'total_jobs': 'int',
        'jobs_created': 'int',
        'batch_jobs_per_seed': 'int',
        'invocations_per_batch_job': 'int',
        'seed_job_definition_id': 'str',
        'monitor_job_definition_id': 'str',
        'batch_job_definition_id': 'str',
        'suspended': 'bool',
        'tenant_id': 'str',
        'create_user_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'total_jobs': 'totalJobs',
        'jobs_created': 'jobsCreated',
        'batch_jobs_per_seed': 'batchJobsPerSeed',
        'invocations_per_batch_job': 'invocationsPerBatchJob',
        'seed_job_definition_id': 'seedJobDefinitionId',
        'monitor_job_definition_id': 'monitorJobDefinitionId',
        'batch_job_definition_id': 'batchJobDefinitionId',
        'suspended': 'suspended',
        'tenant_id': 'tenantId',
        'create_user_id': 'createUserId'
    }

    def __init__(self, id=None, type=None, total_jobs=None, jobs_created=None, batch_jobs_per_seed=None, invocations_per_batch_job=None, seed_job_definition_id=None, monitor_job_definition_id=None, batch_job_definition_id=None, suspended=None, tenant_id=None, create_user_id=None, local_vars_configuration=None):  # noqa: E501
        """BatchDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._type = None
        self._total_jobs = None
        self._jobs_created = None
        self._batch_jobs_per_seed = None
        self._invocations_per_batch_job = None
        self._seed_job_definition_id = None
        self._monitor_job_definition_id = None
        self._batch_job_definition_id = None
        self._suspended = None
        self._tenant_id = None
        self._create_user_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if total_jobs is not None:
            self.total_jobs = total_jobs
        if jobs_created is not None:
            self.jobs_created = jobs_created
        if batch_jobs_per_seed is not None:
            self.batch_jobs_per_seed = batch_jobs_per_seed
        if invocations_per_batch_job is not None:
            self.invocations_per_batch_job = invocations_per_batch_job
        if seed_job_definition_id is not None:
            self.seed_job_definition_id = seed_job_definition_id
        if monitor_job_definition_id is not None:
            self.monitor_job_definition_id = monitor_job_definition_id
        if batch_job_definition_id is not None:
            self.batch_job_definition_id = batch_job_definition_id
        if suspended is not None:
            self.suspended = suspended
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if create_user_id is not None:
            self.create_user_id = create_user_id

    @property
    def id(self):
        """Gets the id of this BatchDto.  # noqa: E501

        The id of the batch.  # noqa: E501

        :return: The id of this BatchDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BatchDto.

        The id of the batch.  # noqa: E501

        :param id: The id of this BatchDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this BatchDto.  # noqa: E501

        The type of the batch.  # noqa: E501

        :return: The type of this BatchDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BatchDto.

        The type of the batch.  # noqa: E501

        :param type: The type of this BatchDto.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def total_jobs(self):
        """Gets the total_jobs of this BatchDto.  # noqa: E501

        The total jobs of a batch is the number of batch execution jobs required to complete the batch.  # noqa: E501

        :return: The total_jobs of this BatchDto.  # noqa: E501
        :rtype: int
        """
        return self._total_jobs

    @total_jobs.setter
    def total_jobs(self, total_jobs):
        """Sets the total_jobs of this BatchDto.

        The total jobs of a batch is the number of batch execution jobs required to complete the batch.  # noqa: E501

        :param total_jobs: The total_jobs of this BatchDto.  # noqa: E501
        :type: int
        """

        self._total_jobs = total_jobs

    @property
    def jobs_created(self):
        """Gets the jobs_created of this BatchDto.  # noqa: E501

        The number of batch execution jobs already created by the seed job.  # noqa: E501

        :return: The jobs_created of this BatchDto.  # noqa: E501
        :rtype: int
        """
        return self._jobs_created

    @jobs_created.setter
    def jobs_created(self, jobs_created):
        """Sets the jobs_created of this BatchDto.

        The number of batch execution jobs already created by the seed job.  # noqa: E501

        :param jobs_created: The jobs_created of this BatchDto.  # noqa: E501
        :type: int
        """

        self._jobs_created = jobs_created

    @property
    def batch_jobs_per_seed(self):
        """Gets the batch_jobs_per_seed of this BatchDto.  # noqa: E501

        The number of batch execution jobs created per seed job invocation. The batch seed job is invoked until it has created all batch execution jobs required by the batch (see totalJobs property).  # noqa: E501

        :return: The batch_jobs_per_seed of this BatchDto.  # noqa: E501
        :rtype: int
        """
        return self._batch_jobs_per_seed

    @batch_jobs_per_seed.setter
    def batch_jobs_per_seed(self, batch_jobs_per_seed):
        """Sets the batch_jobs_per_seed of this BatchDto.

        The number of batch execution jobs created per seed job invocation. The batch seed job is invoked until it has created all batch execution jobs required by the batch (see totalJobs property).  # noqa: E501

        :param batch_jobs_per_seed: The batch_jobs_per_seed of this BatchDto.  # noqa: E501
        :type: int
        """

        self._batch_jobs_per_seed = batch_jobs_per_seed

    @property
    def invocations_per_batch_job(self):
        """Gets the invocations_per_batch_job of this BatchDto.  # noqa: E501

        Every batch execution job invokes the command executed by the batch invocationsPerBatchJob times. E.g., for a process instance migration batch this specifies the number of process instances which are migrated per batch execution job.  # noqa: E501

        :return: The invocations_per_batch_job of this BatchDto.  # noqa: E501
        :rtype: int
        """
        return self._invocations_per_batch_job

    @invocations_per_batch_job.setter
    def invocations_per_batch_job(self, invocations_per_batch_job):
        """Sets the invocations_per_batch_job of this BatchDto.

        Every batch execution job invokes the command executed by the batch invocationsPerBatchJob times. E.g., for a process instance migration batch this specifies the number of process instances which are migrated per batch execution job.  # noqa: E501

        :param invocations_per_batch_job: The invocations_per_batch_job of this BatchDto.  # noqa: E501
        :type: int
        """

        self._invocations_per_batch_job = invocations_per_batch_job

    @property
    def seed_job_definition_id(self):
        """Gets the seed_job_definition_id of this BatchDto.  # noqa: E501

        The job definition id for the seed jobs of this batch.  # noqa: E501

        :return: The seed_job_definition_id of this BatchDto.  # noqa: E501
        :rtype: str
        """
        return self._seed_job_definition_id

    @seed_job_definition_id.setter
    def seed_job_definition_id(self, seed_job_definition_id):
        """Sets the seed_job_definition_id of this BatchDto.

        The job definition id for the seed jobs of this batch.  # noqa: E501

        :param seed_job_definition_id: The seed_job_definition_id of this BatchDto.  # noqa: E501
        :type: str
        """

        self._seed_job_definition_id = seed_job_definition_id

    @property
    def monitor_job_definition_id(self):
        """Gets the monitor_job_definition_id of this BatchDto.  # noqa: E501

        The job definition id for the monitor jobs of this batch.  # noqa: E501

        :return: The monitor_job_definition_id of this BatchDto.  # noqa: E501
        :rtype: str
        """
        return self._monitor_job_definition_id

    @monitor_job_definition_id.setter
    def monitor_job_definition_id(self, monitor_job_definition_id):
        """Sets the monitor_job_definition_id of this BatchDto.

        The job definition id for the monitor jobs of this batch.  # noqa: E501

        :param monitor_job_definition_id: The monitor_job_definition_id of this BatchDto.  # noqa: E501
        :type: str
        """

        self._monitor_job_definition_id = monitor_job_definition_id

    @property
    def batch_job_definition_id(self):
        """Gets the batch_job_definition_id of this BatchDto.  # noqa: E501

        The job definition id for the batch execution jobs of this batch.  # noqa: E501

        :return: The batch_job_definition_id of this BatchDto.  # noqa: E501
        :rtype: str
        """
        return self._batch_job_definition_id

    @batch_job_definition_id.setter
    def batch_job_definition_id(self, batch_job_definition_id):
        """Sets the batch_job_definition_id of this BatchDto.

        The job definition id for the batch execution jobs of this batch.  # noqa: E501

        :param batch_job_definition_id: The batch_job_definition_id of this BatchDto.  # noqa: E501
        :type: str
        """

        self._batch_job_definition_id = batch_job_definition_id

    @property
    def suspended(self):
        """Gets the suspended of this BatchDto.  # noqa: E501

        Indicates whether this batch is suspended or not.  # noqa: E501

        :return: The suspended of this BatchDto.  # noqa: E501
        :rtype: bool
        """
        return self._suspended

    @suspended.setter
    def suspended(self, suspended):
        """Sets the suspended of this BatchDto.

        Indicates whether this batch is suspended or not.  # noqa: E501

        :param suspended: The suspended of this BatchDto.  # noqa: E501
        :type: bool
        """

        self._suspended = suspended

    @property
    def tenant_id(self):
        """Gets the tenant_id of this BatchDto.  # noqa: E501

        The tenant id of the batch.  # noqa: E501

        :return: The tenant_id of this BatchDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this BatchDto.

        The tenant id of the batch.  # noqa: E501

        :param tenant_id: The tenant_id of this BatchDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def create_user_id(self):
        """Gets the create_user_id of this BatchDto.  # noqa: E501

        The id of the user that created the batch.  # noqa: E501

        :return: The create_user_id of this BatchDto.  # noqa: E501
        :rtype: str
        """
        return self._create_user_id

    @create_user_id.setter
    def create_user_id(self, create_user_id):
        """Sets the create_user_id of this BatchDto.

        The id of the user that created the batch.  # noqa: E501

        :param create_user_id: The create_user_id of this BatchDto.  # noqa: E501
        :type: str
        """

        self._create_user_id = create_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BatchDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.attachment_dto import AttachmentDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestAttachmentDto(unittest.TestCase):
    """AttachmentDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AttachmentDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.attachment_dto.AttachmentDto()  # noqa: E501
        if include_optional :
            return AttachmentDto(
                id = '0', 
                name = '0', 
                description = '0', 
                task_id = '0', 
                type = '0', 
                url = '0', 
                create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                removal_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                root_process_instance_id = '0', 
                links = [
                    generic_camunda_client.models.atom_link.AtomLink(
                        rel = '0', 
                        href = '0', 
                        method = '0', )
                    ]
            )
        else :
            return AttachmentDto(
        )

    def testAttachmentDto(self):
        """Test AttachmentDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.user_api import UserApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_available_operations(self):
        """Test case for available_operations

        Options  # noqa: E501
        """
        pass

    def test_available_user_operations(self):
        """Test case for available_user_operations

        Options  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete  # noqa: E501
        """
        pass

    def test_get_user_count(self):
        """Test case for get_user_count

        Get List Count  # noqa: E501
        """
        pass

    def test_get_user_profile(self):
        """Test case for get_user_profile

        Get Profile  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Get List  # noqa: E501
        """
        pass

    def test_unlock_user(self):
        """Test case for unlock_user

        Unlock User  # noqa: E501
        """
        pass

    def test_update_credentials(self):
        """Test case for update_credentials

        Update Credentials  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class IncidentStatisticsResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'incident_type': 'str',
        'incident_count': 'int'
    }

    attribute_map = {
        'incident_type': 'incidentType',
        'incident_count': 'incidentCount'
    }

    def __init__(self, incident_type=None, incident_count=None, local_vars_configuration=None):  # noqa: E501
        """IncidentStatisticsResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._incident_type = None
        self._incident_count = None
        self.discriminator = None

        if incident_type is not None:
            self.incident_type = incident_type
        if incident_count is not None:
            self.incident_count = incident_count

    @property
    def incident_type(self):
        """Gets the incident_type of this IncidentStatisticsResultDto.  # noqa: E501

        The type of the incident the number of incidents is aggregated for. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.  # noqa: E501

        :return: The incident_type of this IncidentStatisticsResultDto.  # noqa: E501
        :rtype: str
        """
        return self._incident_type

    @incident_type.setter
    def incident_type(self, incident_type):
        """Sets the incident_type of this IncidentStatisticsResultDto.

        The type of the incident the number of incidents is aggregated for. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.  # noqa: E501

        :param incident_type: The incident_type of this IncidentStatisticsResultDto.  # noqa: E501
        :type: str
        """

        self._incident_type = incident_type

    @property
    def incident_count(self):
        """Gets the incident_count of this IncidentStatisticsResultDto.  # noqa: E501

        The total number of incidents for the corresponding incident type.  # noqa: E501

        :return: The incident_count of this IncidentStatisticsResultDto.  # noqa: E501
        :rtype: int
        """
        return self._incident_count

    @incident_count.setter
    def incident_count(self, incident_count):
        """Sets the incident_count of this IncidentStatisticsResultDto.

        The total number of incidents for the corresponding incident type.  # noqa: E501

        :param incident_count: The incident_count of this IncidentStatisticsResultDto.  # noqa: E501
        :type: int
        """

        self._incident_count = incident_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncidentStatisticsResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IncidentStatisticsResultDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.process_instance_api import ProcessInstanceApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestProcessInstanceApi(unittest.TestCase):
    """ProcessInstanceApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.process_instance_api.ProcessInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_async_historic_query_based(self):
        """Test case for delete_async_historic_query_based

        """
        pass

    def test_delete_process_instance(self):
        """Test case for delete_process_instance

        """
        pass

    def test_delete_process_instance_variable(self):
        """Test case for delete_process_instance_variable

        """
        pass

    def test_delete_process_instances_async_operation(self):
        """Test case for delete_process_instances_async_operation

        """
        pass

    def test_get_activity_instance_tree(self):
        """Test case for get_activity_instance_tree

        """
        pass

    def test_get_process_instance(self):
        """Test case for get_process_instance

        Get Process Instance  # noqa: E501
        """
        pass

    def test_get_process_instance_variable(self):
        """Test case for get_process_instance_variable

        """
        pass

    def test_get_process_instance_variable_binary(self):
        """Test case for get_process_instance_variable_binary

        """
        pass

    def test_get_process_instance_variables(self):
        """Test case for get_process_instance_variables

        """
        pass

    def test_get_process_instances(self):
        """Test case for get_process_instances

        """
        pass

    def test_get_process_instances_count(self):
        """Test case for get_process_instances_count

        """
        pass

    def test_modify_process_instance(self):
        """Test case for modify_process_instance

        """
        pass

    def test_modify_process_instance_async_operation(self):
        """Test case for modify_process_instance_async_operation

        """
        pass

    def test_modify_process_instance_variables(self):
        """Test case for modify_process_instance_variables

        """
        pass

    def test_query_process_instances(self):
        """Test case for query_process_instances

        """
        pass

    def test_query_process_instances_count(self):
        """Test case for query_process_instances_count

        """
        pass

    def test_set_process_instance_variable(self):
        """Test case for set_process_instance_variable

        """
        pass

    def test_set_process_instance_variable_binary(self):
        """Test case for set_process_instance_variable_binary

        """
        pass

    def test_set_retries_by_process(self):
        """Test case for set_retries_by_process

        """
        pass

    def test_set_retries_by_process_historic_query_based(self):
        """Test case for set_retries_by_process_historic_query_based

        """
        pass

    def test_set_variables_async_operation(self):
        """Test case for set_variables_async_operation

        """
        pass

    def test_update_suspension_state(self):
        """Test case for update_suspension_state

        """
        pass

    def test_update_suspension_state_async_operation(self):
        """Test case for update_suspension_state_async_operation

        """
        pass

    def test_update_suspension_state_by_id(self):
        """Test case for update_suspension_state_by_id

        """
        pass


if __name__ == '__main__':
    unittest.main()
